NAME = "abadpour"

ICON = "📜"

DESCRIPTION = f"{ICON} Arash Abadpour's CV."

VERSION = "6.103.1"

ALIAS = NAME

MARQUEE = (
    "https://github.com/kamangir/assets/blob/main/abadpour/2020-11-21.jpg?raw=true"
)
